<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    width="500px"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="100px"
      class="l-mes"
    >
      <el-form-item label="标签元素描述" prop="itemCode">
        <el-select v-model="dataForm.itemCode" filterable style="width: 100%">
          <el-option
            v-for="item in itemCodeOptions"
            :key="item.id"
            :label="item.itemDesc"
            :value="item.itemCode"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="标题" prop="caption">
        <el-input v-model="dataForm.caption" />
      </el-form-item>
      <el-form-item label="默认值" prop="defaultValue">
        <el-input v-model="dataForm.defaultValue" />
      </el-form-item>
      <el-form-item label="查询sql" prop="qrySql">
        <el-input type="textarea" v-model="dataForm.qrySql" :rows="5" />
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
      >
        确定
      </el-button>
    </span>
  </el-dialog>
</template>
<script>
import { getObj, addObj, putObj } from '@/api/print/configDtl'
import { fetchList as getItemList } from '@/api/print/element'
const dataFormDefault = () => {
  return {
    id: null,
    itemCode: null,
    caption: null,
    defaultValue: null,
    qrySql: null
  }
}
export default {
  props: {
    indexInfo: {
      type: Object,
      default: null
    }
  },
  data() {
    return {
      visible: false,
      dataForm: dataFormDefault(),
      dataRule: {
        itemCode: [
          { required: true, message: '标签元素描述不能为空', trigger: 'blur' }
        ],
        caption: [{ required: true, message: '标题不能为空', trigger: 'blur' }]
      },
      isSubmit: false,
      itemCodeOptions: []
    }
  },
  created() {
    getItemList({
      current: 1,
      size: 999
    }).then((res) => {
      this.itemCodeOptions = res.data.data.records
    })
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj({
              ...this.dataForm,
              mid: this.indexInfo.id
            }).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj({
              ...this.dataForm,
              mid: this.indexInfo.id
            }).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
